@@ -20,7 +20,6 @@
 #include <glib/gi18n-lib.h>
 
 #include "goaprovider.h"
-#include "goaprovider-priv.h"
 #include "goakerberosprovider.h"
 #include "goautils.h"
 #include "goaidentity.h"
@@ -35,13 +34,6 @@ struct _GoaKerberosProvider
   GoaProvider parent_instance;
 };
 
-typedef struct _GoaKerberosProviderClass GoaKerberosProviderClass;
-
-struct _GoaKerberosProviderClass
-{
-  GoaProviderClass parent_class;
-};
-
 static GoaIdentityServiceManager *identity_manager;
 static GMutex identity_manager_mutex;
 static GCond identity_manager_condition;
