@@ -312,6 +312,29 @@ ensure_credentials_sync (GoaProvider         *provider,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
+typedef struct
+{
+  GCancellable *cancellable;
+
+  GtkDialog *dialog;
+  GMainLoop *loop;
+
+  GtkWidget *cluebar;
+  GtkWidget *cluebar_label;
+  GtkWidget *connect_button;
+  GtkWidget *progress_grid;
+
+  GtkWidget *uri;
+  GtkWidget *username;
+  GtkWidget *password;
+
+  gchar *account_object_path;
+
+  GError *error;
+} AddAccountData;
+
+/* ---------------------------------------------------------------------------------------------------- */
+
 static void
 add_entry (GtkWidget     *grid,
            gint           row,
@@ -339,31 +362,6 @@ add_entry (GtkWidget     *grid,
     *out_entry = entry;
 }
 
-/* ---------------------------------------------------------------------------------------------------- */
-
-typedef struct
-{
-  GCancellable *cancellable;
-
-  GtkDialog *dialog;
-  GMainLoop *loop;
-
-  GtkWidget *cluebar;
-  GtkWidget *cluebar_label;
-  GtkWidget *connect_button;
-  GtkWidget *progress_grid;
-
-  GtkWidget *uri;
-  GtkWidget *username;
-  GtkWidget *password;
-
-  gchar *account_object_path;
-
-  GError *error;
-} AddAccountData;
-
-/* ---------------------------------------------------------------------------------------------------- */
-
 static gchar *
 normalize_uri (const gchar *address, gchar **server)
 {
@@ -465,25 +463,6 @@ on_uri_username_or_password_changed (GtkEditable *editable, gpointer user_data)
   g_free (uri);
 }
 
-static void
-show_progress_ui (GtkContainer *container, gboolean progress)
-{
-  GList *children;
-  GList *l;
-
-  children = gtk_container_get_children (container);
-  for (l = children; l != NULL; l = l->next)
-    {
-      GtkWidget *widget = GTK_WIDGET (l->data);
-      gdouble opacity;
-
-      opacity = progress ? 1.0 : 0.0;
-      gtk_widget_set_opacity (widget, opacity);
-    }
-
-  g_list_free (children);
-}
-
 static void
 create_account_details_ui (GoaProvider    *provider,
                            GtkDialog      *dialog,
@@ -582,6 +561,25 @@ create_account_details_ui (GoaProvider    *provider,
     }
 }
 
+static void
+show_progress_ui (GtkContainer *container, gboolean progress)
+{
+  GList *children;
+  GList *l;
+
+  children = gtk_container_get_children (container);
+  for (l = children; l != NULL; l = l->next)
+    {
+      GtkWidget *widget = GTK_WIDGET (l->data);
+      gdouble opacity;
+
+      opacity = progress ? 1.0 : 0.0;
+      gtk_widget_set_opacity (widget, opacity);
+    }
+
+  g_list_free (children);
+}
+
 /* ---------------------------------------------------------------------------------------------------- */
 
 static void
@@ -728,7 +726,7 @@ add_account (GoaProvider    *provider,
         }
 
       markup = g_strdup_printf ("<b>%s:</b>\n%s",
-                                _("Error connecting to ownCloud server"),
+                                _("Error connecting to Nextcloud server"),
                                 data.error->message);
       g_clear_error (&data.error);
 
@@ -919,7 +917,7 @@ refresh_account (GoaProvider    *provider,
       gchar *markup;
 
       markup = g_strdup_printf ("<b>%s:</b>\n%s",
-                                _("Error connecting to ownCloud server"),
+                                _("Error connecting to Nextcloud server"),
                                 data.error->message);
       g_clear_error (&data.error);
 
