@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2014 Red Hat, Inc.
+ * Copyright © 2014 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,10 +18,11 @@
 
 #include "config.h"
 
-#include <glib/gi18n.h>
 #include <glib-unix.h>
 
+#include <locale.h>
 #include <gio/gio.h>
+#include <libintl.h>
 
 #include "goaidentityservice.h"
 
@@ -34,6 +35,11 @@ main (int    argc,
   GError *error;
   int ret = 1;
 
+  setlocale (LC_ALL, "");
+  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
+
   loop = g_main_loop_new (NULL, FALSE);
   service = goa_identity_service_new ();
 
